#include "ofApp.h"

//--------------------------------------------------------------
void ofApp::setup(){
    //ENVIRONMENT
    ofSetFrameRate(10);
    ofSetCircleResolution(100);
    
    //VIDEO
    vidPlayer.load("fish.mov");
    vidPlayer.play();
    vidPlayer.setLoopState(OF_LOOP_NORMAL);
    
    //SLITSCAN
    ofSetVerticalSync(false);
    ofImage distortionMap;
    distortionMap.load("distortion.png");
 
    slitScan.setup(960, 540,90);
    slitScan.setDelayMap(distortionMap);
    slitScan.setBlending(true);
    slitScan.setTimeDelayAndWidth(0,30);
    
    //openCV code
    colorImg.allocate(960,540);
    grayImage.allocate(960,540);
    grayBg.allocate(960,540);
    grayDiff.allocate(960,540);
    bLearnBakground = true;
    threshold = 10;

}

//--------------------------------------------------------------
void ofApp::update(){
    //openCV code
    bool bNewFrame = false;
    vidPlayer.update();
    bNewFrame = vidPlayer.isFrameNew();
    if(vidPlayer.isFrameNew()){
        slitScan.addImage(vidPlayer);
    }
    
    if (bNewFrame){
        colorImg.setFromPixels(vidPlayer.getPixels());
        grayImage = colorImg;
        if (bLearnBakground == true){
            grayBg = grayImage;		// the = sign copys the pixels from grayImage into grayBg (operator overloading)
            bLearnBakground = false;
        }
        grayDiff.absDiff(grayBg, grayImage);
        grayDiff.threshold(threshold);
        contourFinder.findContours(grayDiff, 20, (340*240)/3, 10, true);	    }

}

//--------------------------------------------------------------
void ofApp::draw(){
   
    //VIDEO
    //ofSetHexColor(0xffffff);
    colorImg.draw(0,0,960,540);
    int nCircles = 50;
   
    //CIRCLES
    for (int i = 0; i < contourFinder.nBlobs; i++){
        if(i==0) ofDrawBitmapString(contourFinder.blobs[i].length,20,20);
        
        
        ofRectangle fishR = contourFinder.blobs[i].boundingRect;
        
        ofFill();
        ofSetColor(255,ofRandom(60,210),ofRandom(25,142), 40);
        
        for(int i=0;i<nCircles;i++){
            ofDrawCircle(ofRandom(fishR.getTopLeft().x,fishR.getTopRight().x),
            ofRandom(fishR.getTopLeft().y,fishR.getBottomLeft().y),
            ofRandom(2,30));
        }
       
        //SLITSCAN
        slitScan.getOutputImage().draw(0, 0);
        
    }
}

//--------------------------------------------------------------
void ofApp::keyPressed(int key){

}

//--------------------------------------------------------------
void ofApp::keyReleased(int key){

}

//--------------------------------------------------------------
void ofApp::mouseMoved(int x, int y ){

}

//--------------------------------------------------------------
void ofApp::mouseDragged(int x, int y, int button){

}

//--------------------------------------------------------------
void ofApp::mousePressed(int x, int y, int button){

}

//--------------------------------------------------------------
void ofApp::mouseReleased(int x, int y, int button){

}

//--------------------------------------------------------------
void ofApp::mouseEntered(int x, int y){

}

//--------------------------------------------------------------
void ofApp::mouseExited(int x, int y){

}

//--------------------------------------------------------------
void ofApp::windowResized(int w, int h){

}

//--------------------------------------------------------------
void ofApp::gotMessage(ofMessage msg){

}

//--------------------------------------------------------------
void ofApp::dragEvent(ofDragInfo dragInfo){ 

}
